fastapi\_contrib package
========================

Subpackages
-----------

.. toctree::

   fastapi_contrib.auth
   fastapi_contrib.common
   fastapi_contrib.db
   fastapi_contrib.serializers
   fastapi_contrib.tracing

Submodules
----------

fastapi\_contrib.conf module
----------------------------

.. automodule:: fastapi_contrib.conf
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.exception\_handlers module
-------------------------------------------

.. automodule:: fastapi_contrib.exception_handlers
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.exceptions module
----------------------------------

.. automodule:: fastapi_contrib.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.pagination module
----------------------------------

.. automodule:: fastapi_contrib.pagination
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.permissions module
-----------------------------------

.. automodule:: fastapi_contrib.permissions
   :members:
   :undoc-members:
   :show-inheritance:

fastapi\_contrib.routes module
------------------------------

.. automodule:: fastapi_contrib.routes
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: fastapi_contrib
   :members:
   :undoc-members:
   :show-inheritance:
